%define ALD_Ver		1.2

%define OrgName rpm

License:      GPL
Summary:      The RPM package management system.
Group:        System Environment/Base
Version:      4.11.1
Release:      0

Requires:     uC-file-magic

Source: %{OrgName}-%{version}.tar.xz
Source1: CROSS-uC.sh
Source2: %{OrgName}-%{version}-check-files-dup
Patch0: uC-%{OrgName}-%{version}.patch

%define DestDir		/Embedded/uC-%{uC_Version}

# -----------------------------------------------------

%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%else
# rpm --target=x86_64/armv6l -ba xxxxx.spec
%define _CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mhard-float
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
# -----------------------------------------------------
Name:         uC-%{OrgName}

%define uC_Version 0.9.33.2

#------------------ CROSS DIR --------------------
%if %{_CROSS}

%if %{_os} == "mingw"
ERROR: target=%{_os} 
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/usr/uC/%{uC_Version}/static/bin

%define __os_install_post %{nil}

%define _srcrpmdir %{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysdir		%{nil}
%define csysbindir	/usr/uC/%{uC_Version}/static/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}

# ------------------- description ------------------------------------
%description
The RPM Package Manager (RPM) is a powerful command line driven
package management system capable of installing, uninstalling,
verifying, querying, and updating software packages. Each software
package consists of an archive of files along with information about
the package like its version, a description, etc.
#-------------------------------
%package tools
Summary:      The RPM package tools rpmspec,rpmgraph,rpm2cpio
Group:        System Environment/Base
%description tools
The RPM package tools
#-------------------------------
%package build
Summary:      The RPM package build tools
Group:        System Environment/Base
%description build
The RPM package build tools
#-------------------------------
%package platform
Summary:      The RPM package all platform files
Group:        System Environment/Base
%description platform
The RPM package all platform files
#-------------------------------
%package perl
Summary:      The RPM package perl files osgideps.pl,perldeps.pl
Group:        System Environment/Base
%description perl
perl files osgideps.pl,perldeps.pl

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{OrgName}-%{version}
%patch0 -b .orig -p0

%if %{_lib} == "lib64"
sed -i s:"/usr/lib/rpm":"/usr/lib64/rpm": configure
sed -i s:"/usr/lib/rpm":"/usr/lib64/rpm": installplatform
sed -i s:"(prefix)/lib/rpm":"(prefix)/lib64/rpm": Makefile.in
sed -i s:"(prefix)/lib/rpm":"(prefix)/lib64/rpm": scripts/Makefile.in
sed -i s:"(prefix)/lib/rpm":"(prefix)/lib64/rpm": fileattrs/Makefile.in
sed -i s:"/usr/lib/rpm":"/usr/lib64/rpm": scripts/check-rpaths
sed -i s:"/usr/lib/rpm":"/usr/lib64/rpm": scripts/check-rpaths-worker
sed -i s:"/usr/lib/rpm":"/usr/lib64/rpm": scripts/rpmdb_loadcvt
sed -i s:"/usr/lib/rpm":"/usr/lib64/rpm": scripts/vpkg-provides.sh
sed -i s:"/usr/lib/rpm":"/usr/lib64/rpm": autodeps/linux.prov
sed -i s:"/usr/lib/rpm":"/usr/lib64/rpm": autodeps/linux.req
%endif

%if %{_target_cpu} == "i386"
sed -i s:"@host_alias@":: macros.in
sed -i s:"@host_cpu@":"i386": macros.in
%endif
%if %{_target_cpu} == "x86_64"
sed -i s:"@host_alias@":: macros.in
sed -i s:"@host_cpu@":"x86_64": macros.in
%endif
%if %{_target_cpu} == "armv6l"
sed -i s:"@host_alias@":: macros.in
sed -i s:"@host_cpu@":"armv6l": macros.in
%endif


# ------------------- Build ------------------------------------------
%Build
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
UCLIBC_GCC_INC_SKIP=%{csysdir}/usr/include
export PATH GCC_NoHostPath UCLIBC_GCC_INC_SKIP


%if %{_target_cpu} == "i386"
OPTFLAGS="--static -Os -march=i486 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if (%{_target_cpu} == "x86_64") || (%{_target_cpu} == "win64") 
OPTFLAGS="--static -Os -fomit-frame-pointer"
%endif
%if (%{_target_cpu} == "armv6l") || (%{_target_cpu} == "armv7l")
OPTFLAGS="--static -Os -fno-tree-loop-optimize -march=%{ARM_ARCH} %{ARM_FPU} -fomit-frame-pointer"
%endif


CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections -std=gnu99"
LDFLAGS="-Wl,--gc-sections"
CPPFLAGS="-I%{csysdir}/usr/uC/%{uC_Version}/static/include/beecrypt"

export CFLAGS LDFLAGS CC CPPFLAGS

%if 1
%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
	--enable-static \
	--disable-shared \
	--disable-libtool-lock \
	--disable-nls \
	--disable-python \
	--disable-plugins \
	--without-pic \
	--with-beecrypt \
	--with-external-db \
	--without-libiconv-prefix \
	--without-libintl-prefix \
	--without-lua \
	--without-dmalloc \
	&>FConfigure_log.txt
%endif

make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>Finstall_log.txt

rm -r $RPM_BUILD_ROOT/%{_includedir}
rm $RPM_BUILD_ROOT/%{_libdir}/*.la
rm $RPM_BUILD_ROOT/%{_libdir}/*.a
rm -r $RPM_BUILD_ROOT/%{_libdir}/pkgconfig
#rm $RPM_BUILD_ROOT/%{_libdir}/rpm/rpmdeps
rm -r $RPM_BUILD_ROOT/%{_mandir}/fr
rm -r $RPM_BUILD_ROOT/%{_mandir}/ja
rm -r $RPM_BUILD_ROOT/%{_mandir}/ko
rm -r $RPM_BUILD_ROOT/%{_mandir}/pl
rm -r $RPM_BUILD_ROOT/%{_mandir}/ru
rm -r $RPM_BUILD_ROOT/%{_mandir}/sk

cp COPYING CREDITS GROUPS README doc/manual/* $RPM_BUILD_ROOT%{docdir}/
cp %SOURCE2 $RPM_BUILD_ROOT/%{_libdir}/rpm/check-files-dup

pushd $RPM_BUILD_ROOT/%{_libdir}/rpm
  ln -s /bin/rpm elfdeps
popd

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=0
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%endif #_CROSS


%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 

DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-build-$SE $DD/%{name}-build-$DE
  mv %{name}-platform-$SE $DD/%{name}-platform-$DE
  mv %{name}-tools-$SE $DD/%{name}-tools-$DE
  mv %{name}-perl-$SE $DD/%{name}-perl-$DE
popd

%if %{BUILD_TAR}
# --------------- build *.tgz ------------------------
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%Files
/bin
%{_bindir}/rpmverify
%{_bindir}/rpmquery
%{_libdir}/rpm/elfdeps
%{_libdir}/rpm/macros
%{_libdir}/rpm/rpm.supp
%{_libdir}/rpm/rpmpopt-*
%{_libdir}/rpm/rpmrc
%{_mandir}/man8/rpmsign.8.gz
%{_mandir}/man8/rpmkeys.8.gz
%{_mandir}/man8/rpmdb.8.gz
%{_mandir}/man8/rpm.8.gz

%{docdir}
%{_localstatedir}

%Files tools
%{_bindir}/rpmspec
%{_bindir}/rpmgraph
%{_bindir}/rpm2cpio
%{_libdir}/rpm/rpm2cpio.sh
%{_libdir}/rpm/rpmdb_loadcvt
%{_libdir}/rpm/rpmdeps
%{_mandir}/man8/rpmspec.8.gz
%{_mandir}/man8/rpmgraph.8.gz
%{_mandir}/man8/rpmdeps.8.gz
%{_mandir}/man8/rpm2cpio.8.gz

%Files build
%{_bindir}/gendiff
%{_mandir}/man1/gendiff.1.gz
%{_mandir}/man8/rpmbuild.8.gz
%{_libdir}/rpm/fileattrs
%{_libdir}/rpm/brp-*
%{_libdir}/rpm/check-*
%{_libdir}/rpm/config.*
%{_libdir}/rpm/desktop-file.prov
%{_libdir}/rpm/find-*
%{_libdir}/rpm/fontconfig.prov
%{_libdir}/rpm/libtooldeps.sh
%{_libdir}/rpm/macros.*
%{_libdir}/rpm/mkinstalldirs
%{_libdir}/rpm/mono-find-*
%{_libdir}/rpm/ocaml-find-*
%{_libdir}/rpm/perl.*
%{_libdir}/rpm/pkgconfigdeps.sh
%{_libdir}/rpm/pythondeps.sh
%{_libdir}/rpm/rpm.daily
%{_libdir}/rpm/rpm.log
%{_libdir}/rpm/script.req
%{_libdir}/rpm/tcl.req
%{_libdir}/rpm/tgpg
%if %{_arch} == "arm"
%{_libdir}/rpm/platform/aarch64-linux
%{_libdir}/rpm/platform/armv3l-linux
%{_libdir}/rpm/platform/armv4b-linux
%{_libdir}/rpm/platform/armv4l-linux
%{_libdir}/rpm/platform/armv5tejl-linux
%{_libdir}/rpm/platform/armv5tel-linux
%{_libdir}/rpm/platform/armv6l-linux
%{_libdir}/rpm/platform/armv7l-linux
%else
%{_libdir}/rpm/platform/aarch64-linux
%{_libdir}/rpm/platform/armv5tel-linux
%{_libdir}/rpm/platform/armv6l-linux
%{_libdir}/rpm/platform/armv7l-linux
%{_libdir}/rpm/platform/amd64-linux
%{_libdir}/rpm/platform/athlon-linux
%{_libdir}/rpm/platform/geode-linux
%{_libdir}/rpm/platform/i386-linux
%{_libdir}/rpm/platform/i486-linux
%{_libdir}/rpm/platform/i586-linux
%{_libdir}/rpm/platform/i686-linux
%{_libdir}/rpm/platform/noarch-linux
%{_libdir}/rpm/platform/x86_64-linux
%{_libdir}/rpm/platform/win32-linux
%{_libdir}/rpm/platform/win64-linux
%endif

%Files platform
%if %{_arch} == "arm"
%{_libdir}/rpm/platform/amd64-linux
%{_libdir}/rpm/platform/athlon-linux
%{_libdir}/rpm/platform/geode-linux
%{_libdir}/rpm/platform/i386-linux
%{_libdir}/rpm/platform/i486-linux
%{_libdir}/rpm/platform/i586-linux
%{_libdir}/rpm/platform/i686-linux
%{_libdir}/rpm/platform/noarch-linux
%{_libdir}/rpm/platform/x86_64-linux
%{_libdir}/rpm/platform/win32-linux
%{_libdir}/rpm/platform/win64-linux
%else
%{_libdir}/rpm/platform/armv3l-linux
%{_libdir}/rpm/platform/armv4b-linux
%{_libdir}/rpm/platform/armv4l-linux
%{_libdir}/rpm/platform/armv5tejl-linux
%endif
%{_libdir}/rpm/platform/alpha-linux
%{_libdir}/rpm/platform/alphaev5-linux
%{_libdir}/rpm/platform/alphaev56-linux
%{_libdir}/rpm/platform/alphaev6-linux
%{_libdir}/rpm/platform/alphaev67-linux
%{_libdir}/rpm/platform/alphapca56-linux
%{_libdir}/rpm/platform/ia32e-linux
%{_libdir}/rpm/platform/ia64-linux
%{_libdir}/rpm/platform/pentium3-linux
%{_libdir}/rpm/platform/pentium4-linux
%{_libdir}/rpm/platform/ppc-linux
%{_libdir}/rpm/platform/ppc32dy4-linux
%{_libdir}/rpm/platform/ppc64-linux
%{_libdir}/rpm/platform/ppc64iseries-linux
%{_libdir}/rpm/platform/ppc64p7-linux
%{_libdir}/rpm/platform/ppc64pseries-linux
%{_libdir}/rpm/platform/ppc8260-linux
%{_libdir}/rpm/platform/ppc8560-linux
%{_libdir}/rpm/platform/ppciseries-linux
%{_libdir}/rpm/platform/ppcpseries-linux
%{_libdir}/rpm/platform/s390-linux
%{_libdir}/rpm/platform/s390x-linux
%{_libdir}/rpm/platform/sh-linux
%{_libdir}/rpm/platform/sh3-linux
%{_libdir}/rpm/platform/sh4-linux
%{_libdir}/rpm/platform/sh4a-linux
%{_libdir}/rpm/platform/sparc-linux
%{_libdir}/rpm/platform/sparc64-linux
%{_libdir}/rpm/platform/sparc64v-linux
%{_libdir}/rpm/platform/sparcv8-linux
%{_libdir}/rpm/platform/sparcv9-linux
%{_libdir}/rpm/platform/sparcv9v-linux

%Files perl
%{_libdir}/rpm/osgideps.pl
%{_libdir}/rpm/perldeps.pl
